import * as aws from "aws-sdk";

const sts = new aws.STS();

/**
 * STS Assume Role with SAML
 */
const assumeRoleWithSAMLExample = async () => {
  const params = {
    // Assume Role として引き受けたい IAM Role を指定します。特定のバケットに読み書きを許可するロールなどが相当します。
    RoleArn: "arn:aws:xxxxx:role/S3BucketReadWriteRole",
    // IdP を記述する IAM の SAML プロバイダーの ARN を指定します。AWS コンソールから登録した IAM ID Provider を参照してください。
    PrincipalArn: "arn:aws:xxxxx:saml-provider/keycloak",
    // SAML の認証レスポンスの XML を Base64 エンコードしたものを指定します。
    SAMLAssertion: "Base64-encoded SAML assertion",
  };

  try {
    const res = await sts.assumeRoleWithSAML(params).promise();
    if (res.Credentials) {
      // AssumeRoleWithSAML API から取得した Credential を使用して S3 にアクセスする
      const s3 = new aws.S3({
        accessKeyId: res.Credentials.AccessKeyId,
        secretAccessKey: res.Credentials.SecretAccessKey,
        sessionToken: res.Credentials.SessionToken,
      });
      s3.getObject().promise();
    }
  } catch (err) {
    // err handling
  }
};
